@@ -3,6 +3,8 @@ import base64
 import requests
 
 import os
+import string
+import random
 from uuid import UUID, uuid4
 from binascii import hexlify
 
@@ -25,6 +27,10 @@ class Client(Recall, Socket):
         Recall.__init__(self)
         Socket.__init__(self, self)
 
+    def gen_captcha(self):
+        val = "".join(random.choices(string.ascii_uppercase + string.ascii_lowercase + "_-", k=462)).replace("--", "-")
+        return val
+
     def handle(self, data):
         return self.solve(data)
 
@@ -32,19 +38,45 @@ class Client(Recall, Socket):
         self.headers["NDCLANG"] = lang[0:lang.index("-")]
         self.headers["Accept-Language"] = lang
 
-    def sid_login(self, sid: str):
-        value = str(base64.b64decode(sid.replace("sid=", "")))
-        _value = value.index("{")
-        value_ = value.index("}")
-        value = value[_value: value_ + 1]
-        try: data = json.loads(value)
-        except: raise TypeError(" ")
-        self.uid = data["2"]
+    def sid_login(self, sid: str, uid: str = None):
+        try:
+            value = str(base64.b64decode(sid.replace("sid=", "")))
+            _value = value.index("{")
+            value_ = value.index("}")
+            value = value[_value: value_ + 1]
+            data = json.loads(value)
+            self.uid = data["2"]
+        except:
+            self.uid = uid
         self.sid = f"sid={sid}"
-        headers.uid = self.uid
         headers.sid = self.sid
+        if self.uid:
+            headers.uid = self.uid
+        else:
+            headers.uid = " "
+
+    def login(self, email: str, password: str, isWeb: bool = True):
+        if isWeb:
+            data = {
+                "auth_type": 0,
+                "email": email,
+                "recaptcha_challenge": self.gen_captcha(),
+                "recaptcha_version": "v3",
+                "secret": password
+            }
+            req = requests.post("https://aminoapps.com/api/auth", json=data)
+            if req.status_code != 200: return CheckExceptions(req.json())
+            self.sid = req.headers["set-cookie"]
+            try:
+                self.sid = self.sid[0: self.sid.index(";")]
+            except:
+                self.sid = self.sid
+            self.uid = req.json()["result"]["uid"]
+            self.headers["NDCAUTH"] = self.sid
+            headers.sid = self.sid.replace("sid=", "")
+            headers.uid = self.uid
+            return Json(req.json())
 
-    def login(self, email: str, password=str):
         data = json.dumps({
             "email": email,
             "secret": f"0 {password}",
@@ -66,7 +98,7 @@ class Client(Recall, Socket):
         self.sid = None
         self.uid = None
         self.headers["NDCAUTH"] = None
-        return Json(req.json())
+        return True
 
     def send_verify_code(self, email: str):
         data = json.dumps({
@@ -79,7 +111,8 @@ class Client(Recall, Socket):
         return Json(req.json())
 
     def accept_host(self, requestId: str, chatId: str):
-        req = requests.post(f"{self.api}/g/s/chat/thread/{chatId}/transfer-organizer/{requestId}/accept", headers=self.headers)
+        req = requests.post(f"{self.api}/g/s/chat/thread/{chatId}/transfer-organizer/{requestId}/accept",
+                            headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
@@ -150,9 +183,12 @@ class Client(Recall, Socket):
         return Json(req.json())
 
     def start_chat(self, userId: str = None, title: str = None, message: str = None, content: str = None):
-        if isinstance(userId, str): userIds = [userId]
-        elif isinstance(userId, list): userIds = userId
-        else: raise TypeError("")
+        if isinstance(userId, str):
+            userIds = [userId]
+        elif isinstance(userId, list):
+            userIds = userId
+        else:
+            raise TypeError("")
 
         data = json.dumps({
             "title": title,
@@ -165,9 +201,12 @@ class Client(Recall, Socket):
         return Json(req.json())
 
     def invite_to_chat(self, chatId: str = None, userId: str = None):
-        if isinstance(userId, str): userIds = [userId]
-        elif isinstance(userId, list): userIds = userId
-        else: raise TypeError("")
+        if isinstance(userId, str):
+            userIds = [userId]
+        elif isinstance(userId, list):
+            userIds = userId
+        else:
+            raise TypeError("")
 
         data = json.dumps({"uids": userIds})
         req = requests.post(f'{self.api}/g/s/chat/thread/{chatId}/member/invite', data=data, headers=self.headers)
@@ -246,17 +285,20 @@ class Client(Recall, Socket):
         return Json(req.json())
 
     def get_member_following(self, userId: str, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/g/s/user-profile/{userId}/joined?start={start}&size={size}', headers=self.headers)
+        req = requests.get(f'{self.api}/g/s/user-profile/{userId}/joined?start={start}&size={size}',
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['userProfileList'])
 
     def get_member_followers(self, userId: str, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/g/s/user-profile/{userId}/member?start={start}&size={size}', headers=self.headers)
+        req = requests.get(f'{self.api}/g/s/user-profile/{userId}/member?start={start}&size={size}',
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['userProfileList'])
 
     def get_member_visitors(self, userId: str, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/g/s/user-profile/{userId}/visitors?start={start}&size={size}', headers=self.headers)
+        req = requests.get(f'{self.api}/g/s/user-profile/{userId}/visitors?start={start}&size={size}',
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Visitors(req.json()['visitors'])
 
@@ -273,16 +315,23 @@ class Client(Recall, Socket):
     def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25):
         sorting = sorting.lower()
 
-        if sorting == "newest": sorting = "newest"
-        elif sorting == "oldest": sorting = "oldest"
-        elif sorting == "top": sorting = "vote"
-        else: raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
+        if sorting == "newest":
+            sorting = "newest"
+        elif sorting == "oldest":
+            sorting = "oldest"
+        elif sorting == "top":
+            sorting = "vote"
+        else:
+            raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
 
-        req = requests.get(f"{self.api}/g/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}", headers=self.headers)
+        req = requests.get(f"{self.api}/g/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}",
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Comment(req.json()['commentList'])
 
-    def send_message(self, chatId: str, message: str = None, messageType: int = 0, replyTo: str = None, mentionUserIds: list = None, embedId: str = None, embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None):
+    def send_message(self, chatId: str, message: str = None, messageType: int = 0, replyTo: str = None,
+                     mentionUserIds: list = None, embedId: str = None, embedType: int = None, embedLink: str = None,
+                     embedTitle: str = None, embedContent: str = None):
         uids = []
         if mentionUserIds:
             for uid in mentionUserIds: uids.append({"uid": uid})
@@ -300,16 +349,18 @@ class Client(Recall, Socket):
                 "mentionedArray": uids
             },
         }
-        
+
         if replyTo: data["replyMessageId"] = replyTo
-        
+
         data = json.dumps(data)
         req = requests.post(f"{self.api}/g/s/chat/thread/{chatId}/message/{message}", headers=self.headers, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
     def get_community_info(self, comId: str):
-        req = requests.get(f"{self.api}/g/s-x{comId}/community/info?withInfluencerList=1&withTopicList=true&influencerListOrderStrategy=fansCount", headers=self.headers)
+        req = requests.get(
+            f"{self.api}/g/s-x{comId}/community/info?withInfluencerList=1&withTopicList=true&influencerListOrderStrategy=fansCount",
+            headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Community(req.json()['community'])
 
@@ -324,7 +375,8 @@ class Client(Recall, Socket):
         return Json(req.json())
 
     def get_chat_messages(self, chatId: str, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/g/s/chat/thread/{chatId}/message?v=2&pagingType=t&size={size}', headers=self.headers)
+        req = requests.get(f'{self.api}/g/s/chat/thread/{chatId}/message?v=2&pagingType=t&size={size}',
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return ChatMessages(req.json()['messageList'])
 
@@ -333,7 +385,8 @@ class Client(Recall, Socket):
         if req.status_code != 200: return CheckExceptions(req.json())
         return Message(req.json()['message'])
 
-    def tip_coins(self, chatId: str = None, blogId: str = None, coins: int = 0, transactionId: str = str(UUID(hexlify(os.urandom(16)).decode('ascii')))):
+    def tip_coins(self, chatId: str = None, blogId: str = None, coins: int = 0,
+                  transactionId: str = str(UUID(hexlify(os.urandom(16)).decode('ascii')))):
         data = json.dumps({
             "coins": coins,
             "tippingContext": {
@@ -341,9 +394,12 @@ class Client(Recall, Socket):
             }
         })
 
-        if chatId is not None:api = f'{self.api}/g/s/blog/{chatId}/tipping'
-        elif blogId is not None: api = f"{self.api}/g/s/blog/{blogId}/tipping"
-        else:raise TypeError("")
+        if chatId is not None:
+            api = f'{self.api}/g/s/blog/{chatId}/tipping'
+        elif blogId is not None:
+            api = f"{self.api}/g/s/blog/{blogId}/tipping"
+        else:
+            raise TypeError("")
 
         req = requests.post(api, headers=self.headers, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
@@ -402,7 +458,8 @@ class Client(Recall, Socket):
     def kick(self, chatId: str, userId: str, rejoin: bool = True):
         if rejoin: re = 1
         if not rejoin: re = 0
-        req = requests.delete(f'{self.api}/g/s/chat/thread/{chatId}/member/{userId}?allowRejoin={re}', headers=self.headers)
+        req = requests.delete(f'{self.api}/g/s/chat/thread/{chatId}/member/{userId}?allowRejoin={re}',
+                              headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
@@ -418,7 +475,8 @@ class Client(Recall, Socket):
 
     def invite_to_voice_chat(self, userId: str = None, chatId: str = None):
         data = json.dumps({"uid": userId})
-        req = requests.post(f'{self.api}/g/s/chat/thread/{chatId}/vvchat-presenter/invite', headers=self.headers, data=data)
+        req = requests.post(f'{self.api}/g/s/chat/thread/{chatId}/vvchat-presenter/invite', headers=self.headers,
+                            data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
@@ -438,7 +496,8 @@ class Client(Recall, Socket):
         return UserList(req.json()['userProfileList'])
 
     def get_chat_members(self, start: int = 0, size: int = 25, chatId: str = None):
-        req = requests.get(f"{self.api}/g/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2", headers=self.headers)
+        req = requests.get(f"{self.api}/g/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2",
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['memberList'])
 
@@ -471,7 +530,8 @@ class Client(Recall, Socket):
         if req.status_code != 200: return CheckExceptions(req.json())
         return IdInfo(req.json()['linkInfoV2']['extensions']['linkInfo'])
 
-    def chat_settings(self, chatId: str, viewOnly: bool = None, doNotDisturb: bool = None, canInvite: bool = False, canTip: bool = None, pin: bool = None):
+    def chat_settings(self, chatId: str, viewOnly: bool = None, doNotDisturb: bool = None, canInvite: bool = False,
+                      canTip: bool = None, pin: bool = None):
         res = []
 
         if doNotDisturb is not None:
@@ -526,8 +586,10 @@ class Client(Recall, Socket):
         return Json(req.json())
 
     def unlike_comment(self, commentId: str, blogId: str = None, userId: str = None):
-        if userId: api = f"{self.api}/g/s/user-profile/{userId}/comment/{commentId}/g-vote?eventSource=UserProfileView"
-        elif blogId: api = f"{self.api}/g/s/blog/{blogId}/comment/{commentId}/g-vote?eventSource=PostDetailView"
+        if userId:
+            api = f"{self.api}/g/s/user-profile/{userId}/comment/{commentId}/g-vote?eventSource=UserProfileView"
+        elif blogId:
+            api = f"{self.api}/g/s/blog/{blogId}/comment/{commentId}/g-vote?eventSource=PostDetailView"
         req = requests.delete(api, headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
