@@ -8,6 +8,7 @@ from binascii import hexlify
 
 from samino.lib import *
 from samino.lib import CheckExceptions
+
 # Created By Bovonos -_-
 # Solved-Rewrited-Edited By SirLez too Many Times -_-
 
@@ -18,6 +19,11 @@ class Local:
         elif comId is not None: self.comId = comId
         self.uid = headers.Headers().uid
         self.headers = headers.Headers().headers
+        self.web_headers = {
+            "cookie": f"{self.headers['NDCAUTH']}",
+            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.159 Safari/537.36",
+            "x-requested-with": "xmlhttprequest"
+        }
         self.api = "https://service.narvii.com/api/v1"
 
     # Not now kiddo ._.
@@ -62,36 +68,50 @@ class Local:
     #
     def join_chat(self, chatId: str = None):
         req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}", headers=self.headers)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return Json(req.json())
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return Json(req.json())
 
     def leave_chat(self, chatId: str = None):
         req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}", headers=self.headers)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return Json(req.json())
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return Json(req.json())
 
     def get_member_following(self, userId: str = None, start: int = 0, size: int = 25):
-        req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/joined?start={start}&size={size}", headers=self.headers)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return UserList(req.json()['userProfileList'])
+        req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/joined?start={start}&size={size}",
+                           headers=self.headers)
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return UserList(req.json()['userProfileList'])
 
     def get_member_followers(self, userId: str = None, start: int = 0, size: int = 25):
         req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/joined?start={start}&size={size}")
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return UserList(req.json()['userProfileList'])
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return UserList(req.json()['userProfileList'])
 
     def get_chat_threads(self, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread?type=joined-me&start={start}&size={size}', headers=self.headers)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return MyChats(req.json())
+        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread?type=joined-me&start={start}&size={size}',
+                           headers=self.headers)
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return MyChats(req.json())
 
     def get_member_visitors(self, userId: str, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile/{userId}/visitors?start={start}&size={size}', headers=self.headers)
+        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile/{userId}/visitors?start={start}&size={size}',
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Visitors(req.json()['visitors'])
 
     def get_chat_messages(self, chatId: str, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread/{chatId}/message?v=2&pagingType=t&size={size}', headers=self.headers)
+        req = requests.get(f'{self.api}/x{self.comId}/s/chat/thread/{chatId}/message?v=2&pagingType=t&size={size}',
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return ChatMessages(req.json()['messageList'])
 
@@ -104,89 +124,123 @@ class Local:
                           start: int = 0, size: int = 25):
         sorting = sorting.lower()
 
-        if sorting == "newest": sorting = "newest"
-        elif sorting == "oldest": sorting = "oldest"
-        elif sorting == "top": sorting = "vote"
-        else: raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
+        if sorting == "newest":
+            sorting = "newest"
+        elif sorting == "oldest":
+            sorting = "oldest"
+        elif sorting == "top":
+            sorting = "vote"
+        else:
+            raise TypeError("حط تايب يا حمار")  # Not me typed this its (a7rf)
 
-        req = requests.get(f"{self.api}/x{self.comId}/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}", headers=self.headers)
+        req = requests.get(
+            f"{self.api}/x{self.comId}/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}",
+            headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Comment(req.json()['commentList'])
 
     def get_all_users(self, start: int = 0, size: int = 25):
-        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile?type=recent&start={start}&size={size}', headers=self.headers)
+        req = requests.get(f'{self.api}/x{self.comId}/s/user-profile?type=recent&start={start}&size={size}',
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['userProfileList'])
 
     def get_chat_members(self, start: int = 0, size: int = 25, chatId: str = None):
-        req = requests.get(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2", headers=self.headers)
+        req = requests.get(
+            f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2",
+            headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['memberList'])
 
     def get_online_users(self, start: int = 0, size: int = 25):
-        req = requests.get(f"{self.api}/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:online-members&start={start}&size={size}",  headers=self.headers)
+        req = requests.get(
+            f"{self.api}/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:online-members&start={start}&size={size}",
+            headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return UserList(req.json()['userProfileList'])
 
-    def send_message(self, chatId: str, message: str = None, messageType: int = 0, replyTo: str = None, mentionUserIds: list = None, embedId: str = None, embedType: int = None, embedLink: str = None, embedTitle: str = None, embedContent: str = None, isWeb: bool = False):
+    def send_message(self, chatId: str, message: str = None, messageType: int = 0, replyTo: str = None,
+                     mentionUserIds: list = None, embedId: str = None, embedType: int = None, embedLink: str = None,
+                     embedTitle: str = None, embedContent: str = None, isWeb: bool = False):
         if isWeb:
             data = {
                 "ndcId": f"x{self.comId}",
                 "threadId": chatId,
                 "message": {"content": message, "mediaType": 0, "type": 0, "sendFailed": False, "clientRefId": 0}
             }
-            headers = {
-                "cookie": f"{self.headers['NDCAUTH']}",
-                "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/92.0.4515.159 Safari/537.36",
-                "x-requested-with": "xmlhttprequest"
-            }
-            req = requests.post("https://aminoapps.com/api/add-chat-message", json=data, headers=headers)
-            if req.status_code != 200: return CheckExceptions(req.json())
-            else: return Json(req.json())
-        else:
-            uids = []
-            if mentionUserIds:
-                for uid in mentionUserIds:
-                    uids.append({"uid": uid})
+            req = requests.post("https://aminoapps.com/api/add-chat-message", json=data, headers=self.web_headers)
+            if req.status_code != 200:
+                return CheckExceptions(req.json())
+            else:
+                return Json(req.json())
+
+        uids = []
+        if mentionUserIds:
+            for uid in mentionUserIds:
+                uids.append({"uid": uid})
+        data = {
+            "type": messageType,
+            "content": message,
+            "attachedObject": {
+                "objectId": embedId,
+                "objectType": embedType,
+                "link": embedLink,
+                "title": embedTitle,
+                "content": embedContent
+            },
+            "extensions": {
+                "mentionedArray": uids
+            },
+        }
+        if replyTo: data["replyMessageId"] = replyTo
+        data = json.dumps(data)
+        req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/message", headers=self.headers, data=data)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return Json(req.json())
+
+    def unfollow(self, userId: str, isWeb: bool = False):
+        if isWeb:
             data = {
-                "type": messageType,
-                "content": message,
-                "attachedObject": {
-                    "objectId": embedId,
-                    "objectType": embedType,
-                    "link": embedLink,
-                    "title": embedTitle,
-                    "content": embedContent
-                },
-                "extensions": {
-                    "mentionedArray": uids
-                },
+                "ndcId": f"x{self.comId}",
+                "followee_id": userId,
+                "follower_id": self.uid
             }
-            if replyTo: data["replyMessageId"] = replyTo
-            data = json.dumps(data)
-            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/message", headers=self.headers, data=data)
+            req = requests.post("https://aminoapps.com/api/unfollow-user", json=data, headers=self.web_headers)
             if req.status_code != 200: return CheckExceptions(req.json())
             return Json(req.json())
 
-    def unfollow(self, userId: str):
         req = requests.post(f"{self.api}/g/s/user-profile/{userId}/member/{self.uid}", headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def follow(self, userId: [str, list]):
+    def follow(self, userId: [str, list], isWeb: bool = False):
+        if isWeb:
+            data = {
+                "ndcId": f"x{self.comId}",
+                "followee_id": userId
+            }
+            req = requests.post("https://aminoapps.com/api/follow-user", json=data, headers=self.web_headers)
+            if req.status_code != 200: return CheckExceptions(req.json())
+            return Json(req.json())
+
         data = {}
-        
+
         if isinstance(userId, str): api = f"{self.api}/x{self.comId}/s/user-profile/{userId}/member"
-        if isinstance(userId, list): api = f'{self.api}/x{self.comId}/s/user-profile/{self.uid}/joined'; data = json.dumps({"targetUidList": userId})
-        
+        if isinstance(userId,
+                      list): api = f'{self.api}/x{self.comId}/s/user-profile/{self.uid}/joined'; data = json.dumps(
+            {"targetUidList": userId})
+
         req = requests.post(api, headers=self.headers, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
     def start_chat(self, userId: [str, list], title: str = None, message: str = None, content: str = None):
-        if isinstance(userId, str): userIds = [userId]
-        elif isinstance(userId, list): userIds = userId
-        else: raise TypeError("")
+        if isinstance(userId, str):
+            userIds = [userId]
+        elif isinstance(userId, list):
+            userIds = userId
+        else:
+            raise TypeError("")
 
         data = json.dumps({
             "title": title,
@@ -199,12 +253,16 @@ class Local:
         return Json(req.json())
 
     def invite_to_chat(self, userId: [str, list], chatId: str = None):
-        if isinstance(userId, str): userIds = [userId]
-        elif isinstance(userId, list): userIds = userId
-        else: raise TypeError("")
-        
+        if isinstance(userId, str):
+            userIds = [userId]
+        elif isinstance(userId, list):
+            userIds = userId
+        else:
+            raise TypeError("")
+
         data = json.dumps({"uids": userIds})
-        req = requests.post(f'{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/invite', data=data, headers=self.headers)
+        req = requests.post(f'{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/invite', data=data,
+                            headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
@@ -237,7 +295,8 @@ class Local:
             data["extensions"] = {"pinAnnouncement": pinAnnouncement}
         if background:
             data = json.dumps({"media": [100, background, None]})
-            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}/background", data=data, headers=self.headers)
+            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}/background",
+                                data=data, headers=self.headers)
             if req.status_code != 200: return CheckExceptions(req.json())
             res.append(Json(req.json()))
 
@@ -255,28 +314,32 @@ class Local:
             if doNotDisturb: opt = 2
             if not doNotDisturb: opt = 1
             data = json.dumps({"alertOption": opt})
-            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}/alert", data=data, headers=self.headers)
+            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{self.uid}/alert", data=data,
+                                headers=self.headers)
             if req.status_code != 200: return CheckExceptions(req.json())
             res.append(Json(req.json()))
 
         if viewOnly is not None:
             if viewOnly: viewOnly = "enable"
             if not viewOnly: viewOnly = "disable"
-            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/view-only/{viewOnly}", headers=self.headers)
+            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/view-only/{viewOnly}",
+                                headers=self.headers)
             if req.status_code != 200: return CheckExceptions(req.json())
             res.append(Json(req.json()))
 
         if canInvite is not None:
             if canInvite: canInvite = "enable"
             if not canInvite: canInvite = "disable"
-            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/members-can-invite/{canInvite}", headers=self.headers)
+            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/members-can-invite/{canInvite}",
+                                headers=self.headers)
             if req.status_code != 200: return CheckExceptions(req.json())
             res.append(Json(req.json()))
 
         if canTip is not None:
             if canTip: canTip = "enable"
             if not canTip: canTip = "disable"
-            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/tipping-perm-status/{canTip}", headers=self.headers)
+            req = requests.post(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/tipping-perm-status/{canTip}",
+                                headers=self.headers)
             if req.status_code != 200: return CheckExceptions(req.json())
             res.append(Json(req.json()))
 
@@ -303,10 +366,13 @@ class Local:
 
               - **Fail** : :meth:`Exceptions <samino.lib.exceptions>`
         """
-        if value != 1: pass
-        elif value != -1: raise TypeError(f"Please fill the value by (-1 or 1) not ({value})")
+        if value != 1:
+            pass
+        elif value != -1:
+            raise TypeError(f"Please fill the value by (-1 or 1) not ({value})")
         data = json.dumps({"value": value})
-        req = requests.post(f"{self.api}/x{self.comId}/s/blog/{blogId}/comment/{commentId}/vote?cv=1.2&value=1", data=data, headers=self.headers)
+        req = requests.post(f"{self.api}/x{self.comId}/s/blog/{blogId}/comment/{commentId}/vote?cv=1.2&value=1",
+                            data=data, headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
@@ -353,11 +419,14 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def comment(self, comment: str, userId: str = None, blogId: str = None, wikiId: str = None, replyTo: str = None, isGuest: bool = False):
+    def comment(self, comment: str, userId: str = None, blogId: str = None, wikiId: str = None, replyTo: str = None,
+                isGuest: bool = False):
         data = {"content": comment}
         if replyTo: data["respondTo"] = replyTo
-        if isGuest: comType = "g-comment"
-        else: comType = "comment"
+        if isGuest:
+            comType = "g-comment"
+        else:
+            comType = "comment"
         if userId: api = f"{self.api}/x{self.comId}/s/user-profile/{userId}/{comType}"
         if blogId: api = f"{self.api}/x{self.comId}/s/blog/{blogId}/{comType}"
         if wikiId: api = f"{self.api}/x{self.comId}/s/item/{wikiId}/{comType}"
@@ -369,15 +438,18 @@ class Local:
     def delete_comment(self, commentId: str, userId: str = None, blogId: str = None, wikiId: str = None):
         if userId: api = f"{self.api}/x{self.comId}/s/user-profile/{userId}/comment/{commentId}"
         if blogId: api = f"{self.api}/x{self.comId}/s/blog/{blogId}/comment/{commentId}"
-        if wikiId: api = f"{self.api}/x{self.comId}/s/item/{wikiId}/comment/{commentId}"
-        else: raise TypeError(" ")
+        if wikiId:
+            api = f"{self.api}/x{self.comId}/s/item/{wikiId}/comment/{commentId}"
+        else:
+            raise TypeError(" ")
         req = requests.delete(api, headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
     def vote_poll(self, blogId: str, optionId: str):
         data = json.dumps({"value": 1})
-        req = requests.post(f"{self.api}/x{self.comId}/s/blog/{blogId}/poll/option/{optionId}/vote", headers=self.headers, data=data)
+        req = requests.post(f"{self.api}/x{self.comId}/s/blog/{blogId}/poll/option/{optionId}/vote",
+                            headers=self.headers, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
@@ -389,19 +461,25 @@ class Local:
         return BlogInfo(req.json()["blog"])
 
     def get_blogs(self, start: int = 0, size: int = 25):
-        req = requests.get(url=f"{self.api}/x{self.comId}/s/feed/featured?start={start}&size={size}", headers=self.headers)
+        req = requests.get(url=f"{self.api}/x{self.comId}/s/feed/featured?start={start}&size={size}",
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return BlogList(req.json()["featuredList"])
 
     def get_blogs_more(self, start: int = 0, size: int = 25):
-        req = requests.get(url=f"{self.api}/x{self.comId}/s/feed/featured-more?start={start}&size={size}", headers=self.headers)
+        req = requests.get(url=f"{self.api}/x{self.comId}/s/feed/featured-more?start={start}&size={size}",
+                           headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return BlogList(req.json()["blogList"])
 
     def get_blogs_all(self, start: int = 0, size: int = 25, pagingType: str = "t"):
-        req = requests.get(url=f"{self.api}/x{self.comId}/s/feed/blog-all?pagingType={pagingType}&start={start}&size={size}", headers=self.headers)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return BlogListAll(req.json()["blogList"])
+        req = requests.get(
+            url=f"{self.api}/x{self.comId}/s/feed/blog-all?pagingType={pagingType}&start={start}&size={size}",
+            headers=self.headers)
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return BlogListAll(req.json()["blogList"])
 
     def tip_coins(self, coins: int, chatId: str = None, blogId: str = None, wikiId: str = None,
                   transactionId: str = None):
@@ -416,20 +494,26 @@ class Local:
         if wikiId: api = f"{self.api}/x{self.comId}/s/tipping"; data["objectType"] = 2; data["objectId"] = wikiId
         data = json.dumps(data)
         req = requests.post(url=api, headers=self.headers, data=data)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return Json(req.json())
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return Json(req.json())
 
     def check_in(self, timezone: int = 180):
         data = json.dumps({"timezone": timezone})
         req = requests.post(url=f"{self.api}/x{self.comId}/s/check-in", headers=self.headers, data=data)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return Json(req.json())
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return Json(req.json())
 
     def check_in_lottery(self, timezone: int = 180):
         data = json.dumps({"timezone": timezone})
         req = requests.post(url=f"{self.api}/x{self.comId}/s/check-in/lottery", headers=self.headers, data=data)
-        if req.status_code != 200: return CheckExceptions(req.json())
-        else: return Json(req.json())
+        if req.status_code != 200:
+            return CheckExceptions(req.json())
+        else:
+            return Json(req.json())
 
     def delete_message(self, chatId: str, messageId: str):
         req = requests.delete(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/message/{messageId}", headers=self.headers)
@@ -438,7 +522,8 @@ class Local:
 
     def invite_by_host(self, chatId: str, userId: [str, list]):
         data = json.dumps({"uidList": userId})
-        req = requests.post(url=f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/avchat-members", headers=self.headers, data=data)
+        req = requests.post(url=f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/avchat-members", headers=self.headers,
+                            data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
@@ -535,7 +620,8 @@ class Local:
 
     def invite_to_voice_chat(self, userId: str = None, chatId: str = None):
         data = json.dumps({"uid": userId})
-        req = requests.post(f'{self.api}/g/x{self.comId}/chat/thread/{chatId}/vvchat-presenter/invite', headers=self.headers, data=data)
+        req = requests.post(f'{self.api}/g/x{self.comId}/chat/thread/{chatId}/vvchat-presenter/invite',
+                            headers=self.headers, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
@@ -557,7 +643,8 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def post_wiki(self, title: str, content: str, fansOnly: bool = False, icon: str = None, backgroundColor: str = None):
+    def post_wiki(self, title: str, content: str, fansOnly: bool = False, icon: str = None,
+                  backgroundColor: str = None):
         data = {
             "extensions": {
                 "fansOnly": fansOnly,
@@ -594,11 +681,13 @@ class Local:
             "onlineStatus": status,
             "duration": 86400
         })
-        req = requests.post(f"{self.api}/x{self.comId}/s/user-profile/{self.uid}/online-status", data=data, headers=self.headers)
+        req = requests.post(f"{self.api}/x{self.comId}/s/user-profile/{self.uid}/online-status", data=data,
+                            headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def subscribe(self, userId: str, autoRenew: str = False, transactionId: str = str(UUID(hexlify(os.urandom(16)).decode('ascii')))):
+    def subscribe(self, userId: str, autoRenew: str = False,
+                  transactionId: str = str(UUID(hexlify(os.urandom(16)).decode('ascii')))):
         data = json.dumps({
             "paymentContext": {
                 "transactionId": transactionId,
@@ -617,7 +706,8 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
-    def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False, background: BinaryIO = None, backgroundColor: str = None):
+    def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False,
+                  background: BinaryIO = None, backgroundColor: str = None):
         data = {
             "title": title,
             "content": content
@@ -630,33 +720,43 @@ class Local:
         req = requests.post(api, headers=self.headers, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
-        
+
     def get_chat_bubbles(self, start: int = 0, size: int = 20):
-      req = requests.get(url=f"{self.api}/x{self.comId}/s/chat/chat-bubble?type=all-my-bubbles&start={start}&size={size}", headers=self.headers)
-      if req.status_code != 200: return CheckExceptions(req.json())
-      return BubbleList(req.json()["chatBubbleList"])
-    
+        req = requests.get(
+            url=f"{self.api}/x{self.comId}/s/chat/chat-bubble?type=all-my-bubbles&start={start}&size={size}",
+            headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        return BubbleList(req.json()["chatBubbleList"])
+
     def select_bubble(self, bubbleId: str, apply: int = 0, chatId: str = None):
-      data = {
-        "bubbleId": bubbleId,
-        "applyToAll": apply
-      }
-      if chatId: data["threadId"] = chatId
-      req = requests.post(url=f"{self.api}/x{self.comId}/s/chat/thread/apply-bubble", headers=self.headers, data=json.dumps(data))
-      if req.status_code != 200: return CheckExceptions(req.json())
-      else: return Json(req.json())
-    
-    def delete_chat_bubble(self , bubbleId: str):
-      req = requests.delete(url=f"{self.api}/x{self.comId}/s/chat/chat-bubble/{bubbleId}", headers=self.headers)
-      if req.status_code != 200: return CheckExceptions(req.json())
-      else: return Json(req.json())
-    
+        data = {
+            "bubbleId": bubbleId,
+            "applyToAll": apply
+        }
+        if chatId: data["threadId"] = chatId
+        req = requests.post(url=f"{self.api}/x{self.comId}/s/chat/thread/apply-bubble", headers=self.headers, data=json.dumps(data))
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else:return Json(req.json())
+
+    def delete_chat_bubble(self, bubbleId: str):
+        req = requests.delete(url=f"{self.api}/x{self.comId}/s/chat/chat-bubble/{bubbleId}", headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return Json(req.json())
+
     def get_chat_bubble_templates(self, start: int = 0, size: int = 25):
-      req = requests.get(url=f"{self.api}/x{self.comId}/s/chat/chat-bubble/templates?start={start}&size={size}", headers=self.headers)
-      if req.status_code != 200: return CheckExceptions(req.json())
-      else: return BubbleTemplates(req.json()["templateList"])
+        req = requests.get(url=f"{self.api}/x{self.comId}/s/chat/chat-bubble/templates?start={start}&size={size}", headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return BubbleTemplates(req.json()["templateList"])
 
     def upload_custom_bubble(self, templateId: str, bubble: BinaryIO):
-      req = requests.post(url=f"{self.api}/x{self.comId}/s/chat/chat-bubble/templates/{templateId}/generate", headers=self.headers, data=bubble)
-      if req.status_code != 200: return CheckExceptions(req.json())
-      else: return Json(req.json())
+        req = requests.post(url=f"{self.api}/x{self.comId}/s/chat/chat-bubble/templates/{templateId}/generate", headers=self.headers, data=bubble)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return Json(req.json())
+
+    def kick(self, chatId: str, userId: str, allowRejoin: bool = True):
+        if not allowRejoin: allowRejoin = 1
+        if allowRejoin: allowRejoin = 0
+        req = requests.delete(f"{self.api}/x{self.comId}/s/chat/thread/{chatId}/member/{userId}?allowRejoin={allowRejoin}", headers=self.headers)
+        if req.status_code != 200: return CheckExceptions(req.json())
+        else: return Json(req.json())
+
